@@ -49,9 +49,11 @@ void Account::get(const QUrl &url,
                   bool authenticated,
                   QObject *parent,
                   std::function<void(QNetworkReply *)> reply_cb,
-                  std::function<void(QNetworkReply *)> errorCallback)
+                  std::function<void(QNetworkReply *)> errorCallback,
+                  bool fallible)
 {
     QNetworkRequest request = makeRequest(url, authenticated);
+    request.setAttribute(QNetworkRequest::Attribute::User, fallible);
     qCDebug(TOKODON_HTTP) << "GET" << url;
 
     QNetworkReply *reply = m_qnam->get(request);
@@ -178,7 +180,9 @@ void Account::handleReply(QNetworkReply *reply, std::function<void(QNetworkReply
 {
     connect(reply, &QNetworkReply::finished, [reply, reply_cb, errorCallback]() {
         reply->deleteLater();
-        if (200 != reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) && !reply->url().toString().contains("nodeinfo"_L1)) {
+        // these are usually (sometimes meant to be) fallible and end up spamming user logs with these errors
+        const auto fallible = reply->request().attribute(QNetworkRequest::Attribute::User).toBool();
+        if (200 != reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) && !fallible) {
             NetworkController::instance().logError(reply->url().toString(), reply->errorString());
             if (errorCallback) {
                 errorCallback(reply);
@@ -318,17 +322,26 @@ void Account::validateToken()
             Q_EMIT authenticated(true, {});
 
 #ifdef HAVE_KUNIFIEDPUSH
+            // Query whether or not we have a valid push subscription from the server.
             get(
                 apiUrl(QStringLiteral("/api/v1/push/subscription")),
                 true,
                 this,
                 [this](QNetworkReply *reply) {
+                    // If the error code is success, then we *do* have a subscription.
                     m_hasPushSubscription = true;
 
                     const QJsonDocument doc = QJsonDocument::fromJson(reply->readAll());
 
+                    // Sometimes - for some reason - we get a successful HTTP code but it's actually an error. Skip!
+                    if (doc.object().contains("error"_L1)) {
+                        m_hasPushSubscription = false;
+                        return;
+                    }
+
                     if (!NetworkController::instance().endpoint.isEmpty() && doc["endpoint"_L1] != NetworkController::instance().endpoint) {
-                        qWarning(TOKODON_LOG) << "KUnifiedPush endpoint has changed to" << NetworkController::instance().endpoint << ", resubscribing!";
+                        qWarning(TOKODON_LOG) << "KUnifiedPush endpoint is now" << NetworkController::instance().endpoint << "and the old one was"
+                                              << doc["endpoint"_L1] << "resubscribing!";
 
                         deleteResource(apiUrl(QStringLiteral("/api/v1/push/subscription")), true, this, [this](QNetworkReply *reply) {
                             Q_UNUSED(reply)
@@ -341,9 +354,11 @@ void Account::validateToken()
                 },
                 [this](QNetworkReply *reply) {
                     Q_UNUSED(reply);
+                    // Otherwise, no subscription.
                     m_hasPushSubscription = false;
-                    updatePushNotifications();
-                });
+                },
+                true // otherwise it tends to spam your error log
+            );
 #endif
         },
         [this](QNetworkReply *reply) {
@@ -536,7 +551,6 @@ QUrlQuery Account::buildNotificationFormData()
     addQuery(QStringLiteral("update"), cfg->notifyUpdate());
     addQuery(QStringLiteral("admin.sign_up"), cfg->notifySignup());
     addQuery(QStringLiteral("admin.report"), cfg->notifyReport());
-    addQuery(QStringLiteral("annual_report"), cfg->notifyAnnualReport());
 
     return formdata;
 }
