@@ -3,6 +3,9 @@
 
 #include "admin/emailblocktoolmodel.h"
 
+#include <QJsonDocument>
+#include <QNetworkReply>
+
 #include "account/accountmanager.h"
 #include "texthandler.h"
 
@@ -76,7 +79,7 @@ void EmailBlockToolModel::newEmailBlock(const QString &domain)
 
     const QUrl url = account->apiUrl(QStringLiteral("/api/v1/admin/email_domain_blocks"));
 
-    account->post(url, doc, true, this, [=](QNetworkReply *reply) {
+    account->post(url, doc, true, this, [this](QNetworkReply *reply) {
         const auto doc = QJsonDocument::fromJson(reply->readAll());
         const auto jsonObj = doc.object();
         const auto newEmailInfo = EmailInfo::fromSourceData(jsonObj);
@@ -93,13 +96,16 @@ void EmailBlockToolModel::deleteEmailBlock(const int row)
     const auto &emailinfo = m_emailinfo[row];
     const auto emailBlockId = emailinfo.id();
 
-    account->deleteResource(account->apiUrl(QStringLiteral("/api/v1/admin/email_domain_blocks/%1").arg(emailBlockId)), true, this, [=](QNetworkReply *reply) {
-        Q_UNUSED(reply);
-        beginRemoveRows({}, row, row);
-        m_emailinfo.removeAt(row);
-        endRemoveRows();
-        Q_EMIT dataChanged(index(row, 0), index(row, 0));
-    });
+    account->deleteResource(account->apiUrl(QStringLiteral("/api/v1/admin/email_domain_blocks/%1").arg(emailBlockId)),
+                            true,
+                            this,
+                            [this, row](QNetworkReply *reply) {
+                                Q_UNUSED(reply);
+                                beginRemoveRows({}, row, row);
+                                m_emailinfo.removeAt(row);
+                                endRemoveRows();
+                                Q_EMIT dataChanged(index(row, 0), index(row, 0));
+                            });
 }
 
 void EmailBlockToolModel::filltimeline()
@@ -127,11 +133,9 @@ void EmailBlockToolModel::filltimeline()
 
             QList<EmailInfo> fetchedEmailblocks;
 
-            std::transform(
-                emailblocks.cbegin(),
-                emailblocks.cend(),
-                std::back_inserter(fetchedEmailblocks),
-                [=](const QJsonValue &value) -> auto{ return EmailInfo::fromSourceData(value.toObject()); });
+            std::ranges::transform(std::as_const(emailblocks), std::back_inserter(fetchedEmailblocks), [=](const QJsonValue &value) -> auto {
+                return EmailInfo::fromSourceData(value.toObject());
+            });
             beginInsertRows({}, m_emailinfo.size(), m_emailinfo.size() + fetchedEmailblocks.size() - 1);
             m_emailinfo += fetchedEmailblocks;
             endInsertRows();
